==> hibernate-search-mapper-orm-7.2.1.Final.jar: module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.orm {
    /* static phase */ requires jakarta.cdi;
    requires jakarta.persistence;
    requires jakarta.transaction;
    /* transitive */ requires org.hibernate.commons.annotations;
    /* transitive */ requires org.hibernate.orm.core;
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.mapper.pojo;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.jandex;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.orm;
    exports org.hibernate.search.mapper.orm.automaticindexing;
    exports org.hibernate.search.mapper.orm.automaticindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.automaticindexing.session;
    exports org.hibernate.search.mapper.orm.automaticindexing.session.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.automaticindexing.spi;
    exports org.hibernate.search.mapper.orm.bootstrap.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.bootstrap.spi;
    exports org.hibernate.search.mapper.orm.cfg;
    exports org.hibernate.search.mapper.orm.cfg.spi;
    exports org.hibernate.search.mapper.orm.common;
    exports org.hibernate.search.mapper.orm.common.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.common.spi;
    exports org.hibernate.search.mapper.orm.coordination.common.spi;
    exports org.hibernate.search.mapper.orm.coordination.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.entity;
    exports org.hibernate.search.mapper.orm.event.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.loading.spi;
    exports org.hibernate.search.mapper.orm.logging.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.mapping;
    exports org.hibernate.search.mapper.orm.mapping.context;
    exports org.hibernate.search.mapper.orm.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.mapping.spi;
    exports org.hibernate.search.mapper.orm.massindexing;
    exports org.hibernate.search.mapper.orm.massindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.model.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.reporting.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.schema.management;
    exports org.hibernate.search.mapper.orm.schema.management.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.scope;
    exports org.hibernate.search.mapper.orm.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.search.loading;
    exports org.hibernate.search.mapper.orm.search.loading.dsl;
    exports org.hibernate.search.mapper.orm.search.query.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.search.query.spi;
    exports org.hibernate.search.mapper.orm.session;
    exports org.hibernate.search.mapper.orm.session.context;
    exports org.hibernate.search.mapper.orm.session.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.spi;
    exports org.hibernate.search.mapper.orm.tenancy.spi;
    exports org.hibernate.search.mapper.orm.work;
    exports org.hibernate.search.mapper.orm.work.impl to org.hibernate.search.engine;

    provides AdditionalMappingContributor with HibernateSearchCompositeMappingProducer;
    provides Integrator with HibernateSearchIntegrator;
    provides BeanConfigurer with HibernateOrmBeanConfigurer;
    provides ServiceContributor with HibernateSearchContextProviderServiceContributor, HibernateSearchPreIntegrationService.Contributor;

}

==> hibernate-search-mapper-orm-8.1.1.Final.jar: module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.orm {
    /* static phase */ requires jakarta.cdi;
    requires jakarta.persistence;
    requires jakarta.transaction;
    /* transitive */ requires org.hibernate.models;
    /* transitive */ requires org.hibernate.orm.core;
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.mapper.pojo;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.orm;
    exports org.hibernate.search.mapper.orm.automaticindexing;
    exports org.hibernate.search.mapper.orm.automaticindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.automaticindexing.session;
    exports org.hibernate.search.mapper.orm.automaticindexing.session.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.automaticindexing.spi;
    exports org.hibernate.search.mapper.orm.bootstrap.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.bootstrap.spi;
    exports org.hibernate.search.mapper.orm.cfg;
    exports org.hibernate.search.mapper.orm.cfg.spi;
    exports org.hibernate.search.mapper.orm.common;
    exports org.hibernate.search.mapper.orm.common.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.common.spi;
    exports org.hibernate.search.mapper.orm.coordination.common.spi;
    exports org.hibernate.search.mapper.orm.coordination.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.entity;
    exports org.hibernate.search.mapper.orm.event.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.loading.spi;
    exports org.hibernate.search.mapper.orm.logging.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.mapping;
    exports org.hibernate.search.mapper.orm.mapping.context;
    exports org.hibernate.search.mapper.orm.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.mapping.spi;
    exports org.hibernate.search.mapper.orm.massindexing;
    exports org.hibernate.search.mapper.orm.massindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.model.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.reporting.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.schema.management;
    exports org.hibernate.search.mapper.orm.schema.management.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.scope;
    exports org.hibernate.search.mapper.orm.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.search.loading;
    exports org.hibernate.search.mapper.orm.search.loading.dsl;
    exports org.hibernate.search.mapper.orm.search.query.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.search.query.spi;
    exports org.hibernate.search.mapper.orm.session;
    exports org.hibernate.search.mapper.orm.session.context;
    exports org.hibernate.search.mapper.orm.session.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.orm.spi;
    exports org.hibernate.search.mapper.orm.tenancy.spi;
    exports org.hibernate.search.mapper.orm.work;
    exports org.hibernate.search.mapper.orm.work.impl to org.hibernate.search.engine;

    provides AdditionalMappingContributor with HibernateSearchCompositeMappingProducer;
    provides Integrator with HibernateSearchIntegrator;
    provides BeanConfigurer with HibernateOrmBeanConfigurer;
    provides ServiceContributor with HibernateSearchContextProviderServiceContributor, HibernateSearchPreIntegrationService.Contributor;

}
